# Internal documentation

This chapter describes aspects of the Glean SDKs that are internal implementation details.


{{#include ../../../shared/blockquote-warning.html}}

#### Note

> As implementation details, this information is subject to change at any time.
> External users should not rely on this information.
> It is provided as a reference for contributing to Glean only.

This includes:

* [Reserved ping names](reserved-ping-names.md)
* [Clearing metrics when disabling/enabling Glean](clearing.md)
* [Database format](database.md)
* [Payload format](payload.md)
* [Directory structure](directory-structure.md)
* [Debug Pings](debug-pings.md)
* [Implementations](implementations.md)
